==> apache-dolphinscheduler-3.1.9-src.tar.gz: apache-dolphinscheduler-3.1.9-src/dolphinscheduler-task-plugin/dolphinscheduler-task-api/src/main/java/org/apache/dolphinscheduler/plugin/task/api/loop/LoopTaskDefinition.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.dolphinscheduler.plugin.task.api.loop;

import lombok.NonNull;

public interface LoopTaskDefinition<SubmitTaskMethodT extends LoopTaskSubmitTaskMethodDefinition,
    QueryTaskMethodT extends LoopTaskQueryStatusMethodDefinition, CancelTaskMethodT extends LoopTaskCancelMethodDefinition> {
    /**
     * The task name of this loop task, e.g: K8sPodTask
     */
    @NonNull
    String getTaskName();

    /**
     * Submit task method definition, each loop task should contain submit task method.
     */
    @NonNull
    SubmitTaskMethodT getSubmitTaskMethod();

    /**
     * Query task method definition, each loop task should contain query task method.
     */
    @NonNull
    QueryTaskMethodT getQueryTaskStateMethod();

    /**
     * Cancel task method definition, each loop task should contain cancel task method, used to cancel the task instance
     */
    @NonNull
    CancelTaskMethodT getCancelTaskMethod();

}

==> apache-dolphinscheduler-3.3.2-src.tar.gz: apache-dolphinscheduler-3.3.2-src/dolphinscheduler-task-plugin/dolphinscheduler-task-api/src/main/java/org/apache/dolphinscheduler/plugin/task/api/loop/LoopTaskDefinition.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.dolphinscheduler.plugin.task.api.loop;

import lombok.NonNull;

public interface LoopTaskDefinition<SubmitTaskMethodT extends LoopTaskSubmitTaskMethodDefinition, QueryTaskMethodT extends LoopTaskQueryStatusMethodDefinition, CancelTaskMethodT extends LoopTaskCancelMethodDefinition> {

    /**
     * The task name of this loop task, e.g: K8sPodTask
     */
    @NonNull
    String getTaskName();

    /**
     * Submit task method definition, each loop task should contain submit task method.
     */
    @NonNull
    SubmitTaskMethodT getSubmitTaskMethod();

    /**
     * Query task method definition, each loop task should contain query task method.
     */
    @NonNull
    QueryTaskMethodT getQueryTaskStateMethod();

    /**
     * Cancel task method definition, each loop task should contain cancel task method, used to cancel the task instance
     */
    @NonNull
    CancelTaskMethodT getCancelTaskMethod();

}
